==> simple-influx-http-0.0.4.tgz: package/README.md <==
[![Dependencies](https://david-dm.org/k03mad/simple-influx-http.svg)](https://github.com/k03mad/simple-influx-http/blob/master/package.json) [![LCommit](https://img.shields.io/github/last-commit/k03mad/simple-influx-http.svg)](https://github.com/k03mad/simple-influx-http/commits/master)

[![Downloads](https://img.shields.io/npm/dt/simple-influx-http.svg)](https://www.npmjs.com/package/simple-influx-http) [![NPM](https://img.shields.io/npm/v/simple-influx-http.svg)](https://www.npmjs.com/package/simple-influx-http) ![Node](https://img.shields.io/node/v/simple-influx-http.svg)

![Size](https://img.shields.io/github/repo-size/k03mad/simple-influx-http.svg) [![install size](https://packagephobia.now.sh/badge?p=simple-influx-http)](https://packagephobia.now.sh/result?p=simple-influx-http)

## Tiny library for InfluxDB data write

Use command this way:

```js
const {writeToInflux} = require('simple-influx-http');

(async () => {
    await writeToInflux({
        url: 'http://localhost:8086',     // influx http api url with port
        db: 'myData',                     // database name
        meas: 'water',                    // measurement name
        tags: {                           // tags to add
            country: 'russia',
            city: 'sochi',
        },
        values: {                         // values to send
            temp: 24,
            desc: 'good time to swim',
        },
        timestamp: '1476742925219947761', // to add          (default = current)
        retry: 3,                         // superagent request retries (default = 3)
        timeout: {                        // superagent request timeout (default = 10000/20000)
            response: 10000,
            deadline: 20000,
        }
    });
})();
```

==> simple-influx-http-0.0.7.tgz: package/README.md <==
[![Dependencies](https://david-dm.org/k03mad/simple-influx-http.svg)](https://github.com/k03mad/simple-influx-http/blob/master/package.json) [![LCommit](https://img.shields.io/github/last-commit/k03mad/simple-influx-http.svg)](https://github.com/k03mad/simple-influx-http/commits/master)

[![Downloads](https://img.shields.io/npm/dt/simple-influx-http.svg)](https://www.npmjs.com/package/simple-influx-http) [![NPM](https://img.shields.io/npm/v/simple-influx-http.svg)](https://www.npmjs.com/package/simple-influx-http) ![Node](https://img.shields.io/node/v/simple-influx-http.svg)

![Size](https://img.shields.io/github/repo-size/k03mad/simple-influx-http.svg) [![install size](https://packagephobia.now.sh/badge?p=simple-influx-http)](https://packagephobia.now.sh/result?p=simple-influx-http)

## Tiny library for InfluxDB data write

Use command this way:

```js
const {writeToInflux} = require('simple-influx-http');

(async () => {
    await writeToInflux({
        url: 'http://localhost:8086',     // influx http api url with port
        db: 'myData',                     // database name
        meas: 'water',                    // measurement name
        tags: {                           // tags to add
            country: 'russia',
            city: 'sochi',
        },
        values: {                         // values to send
            temp: 24,
            desc: 'good time to swim',
        },
        timestamp: '1476742925219947761', // time to add                (default = current)
        retry: 3,                         // superagent request retries (default = 3)
        timeout: {                        // superagent request timeout (default = 10000/20000)
            response: 10000,
            deadline: 20000,
        }
    });
})();
```
